@@ -18,13 +18,6 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
-const (
-	crbGVR = "rbac.authorization.k8s.io/v1/clusterrolebindings"
-	crGVR  = "rbac.authorization.k8s.io/v1/clusterroles"
-	rbGVR  = "rbac.authorization.k8s.io/v1/rolebindings"
-	rGVR   = "rbac.authorization.k8s.io/v1/roles"
-)
-
 var (
 	_ Accessor = (*Rbac)(nil)
 	_ Nuker    = (*Rbac)(nil)
@@ -37,7 +30,7 @@ type Rbac struct {
 
 // List lists out rbac resources.
 func (r *Rbac) List(ctx context.Context, ns string) ([]runtime.Object, error) {
-	gvr, ok := ctx.Value(internal.KeyGVR).(client.GVR)
+	gvr, ok := ctx.Value(internal.KeyGVR).(*client.GVR)
 	if !ok {
 		return nil, fmt.Errorf("expecting a context gvr")
 	}
@@ -61,23 +54,22 @@ func (r *Rbac) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 }
 
 func (r *Rbac) loadClusterRoleBinding(path string) ([]runtime.Object, error) {
-	o, err := r.getFactory().Get(crbGVR, path, true, labels.Everything())
+	crbo, err := r.getFactory().Get(client.CrbGVR, path, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
-
 	var crb rbacv1.ClusterRoleBinding
-	err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &crb)
+	err = runtime.DefaultUnstructuredConverter.FromUnstructured(crbo.(*unstructured.Unstructured).Object, &crb)
 	if err != nil {
 		return nil, err
 	}
 
-	crbo, err := r.getFactory().Get(crGVR, client.FQN("-", crb.RoleRef.Name), true, labels.Everything())
+	cro, err := r.getFactory().Get(client.CrGVR, client.FQN("-", crb.RoleRef.Name), true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
 	var cr rbacv1.ClusterRole
-	err = runtime.DefaultUnstructuredConverter.FromUnstructured(crbo.(*unstructured.Unstructured).Object, &cr)
+	err = runtime.DefaultUnstructuredConverter.FromUnstructured(crbo.(*unstructured.Unstructured).Object, &cro)
 	if err != nil {
 		return nil, err
 	}
@@ -86,30 +78,29 @@ func (r *Rbac) loadClusterRoleBinding(path string) ([]runtime.Object, error) {
 }
 
 func (r *Rbac) loadRoleBinding(path string) ([]runtime.Object, error) {
-	o, err := r.getFactory().Get(rbGVR, path, true, labels.Everything())
+	rbo, err := r.getFactory().Get(client.RobGVR, path, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
-
 	var rb rbacv1.RoleBinding
-	if err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &rb); err != nil {
-		return nil, err
+	if e := runtime.DefaultUnstructuredConverter.FromUnstructured(rbo.(*unstructured.Unstructured).Object, &rb); e != nil {
+		return nil, e
 	}
 
 	if rb.RoleRef.Kind == "ClusterRole" {
-		o, e := r.getFactory().Get(crGVR, client.FQN("-", rb.RoleRef.Name), true, labels.Everything())
+		cro, e := r.getFactory().Get(client.CrGVR, client.FQN("-", rb.RoleRef.Name), true, labels.Everything())
 		if e != nil {
 			return nil, e
 		}
 		var cr rbacv1.ClusterRole
-		err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &cr)
+		err = runtime.DefaultUnstructuredConverter.FromUnstructured(cro.(*unstructured.Unstructured).Object, &cr)
 		if err != nil {
 			return nil, err
 		}
 		return asRuntimeObjects(parseRules(client.ClusterScope, "-", cr.Rules)), nil
 	}
 
-	ro, err := r.getFactory().Get(rGVR, client.FQN(rb.Namespace, rb.RoleRef.Name), true, labels.Everything())
+	ro, err := r.getFactory().Get(client.RoGVR, client.FQN(rb.Namespace, rb.RoleRef.Name), true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -124,11 +115,10 @@ func (r *Rbac) loadRoleBinding(path string) ([]runtime.Object, error) {
 
 func (r *Rbac) loadClusterRole(fqn string) ([]runtime.Object, error) {
 	slog.Debug("LOAD-CR", slogs.FQN, fqn)
-	o, err := r.getFactory().Get(crGVR, fqn, true, labels.Everything())
+	o, err := r.getFactory().Get(client.CrGVR, fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
-
 	var cr rbacv1.ClusterRole
 	err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &cr)
 	if err != nil {
@@ -139,11 +129,10 @@ func (r *Rbac) loadClusterRole(fqn string) ([]runtime.Object, error) {
 }
 
 func (r *Rbac) loadRole(path string) ([]runtime.Object, error) {
-	o, err := r.getFactory().Get(rGVR, path, true, labels.Everything())
+	o, err := r.getFactory().Get(client.RoGVR, path, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
-
 	var ro rbacv1.Role
 	err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &ro)
 	if err != nil {
