@@ -33,28 +33,6 @@ func TestTruncate(t *testing.T) {
 	}
 }
 
-func TestIsLabelSelector(t *testing.T) {
-	uu := map[string]struct {
-		s  string
-		ok bool
-	}{
-		"empty":       {s: ""},
-		"cool":        {s: "-l app=fred,env=blee", ok: true},
-		"no-flag":     {s: "app=fred,env=blee", ok: true},
-		"no-space":    {s: "-lapp=fred,env=blee", ok: true},
-		"wrong-flag":  {s: "-f app=fred,env=blee"},
-		"missing-key": {s: "=fred"},
-		"missing-val": {s: "fred="},
-	}
-
-	for k := range uu {
-		u := uu[k]
-		t.Run(k, func(t *testing.T) {
-			assert.Equal(t, u.ok, IsLabelSelector(u.s))
-		})
-	}
-}
-
 func TestTrimLabelSelector(t *testing.T) {
 	uu := map[string]struct {
 		sel, e string
