@@ -5,6 +5,7 @@ package view
 
 import (
 	"context"
+	"log/slog"
 	"os"
 	"path/filepath"
 	"strings"
@@ -13,9 +14,10 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/config/data"
+	"github.com/derailed/k9s/internal/render"
+	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
-	"github.com/rs/zerolog/log"
 )
 
 // Benchmark represents a service benchmark results view.
@@ -24,7 +26,7 @@ type Benchmark struct {
 }
 
 // NewBenchmark returns a new viewer.
-func NewBenchmark(gvr client.GVR) ResourceViewer {
+func NewBenchmark(gvr *client.GVR) ResourceViewer {
 	b := Benchmark{
 		ResourceViewer: NewBrowser(gvr),
 	}
@@ -41,7 +43,7 @@ func (b *Benchmark) benchContext(ctx context.Context) context.Context {
 	return context.WithValue(ctx, internal.KeyDir, benchDir(b.App().Config))
 }
 
-func (b *Benchmark) viewBench(app *App, model ui.Tabular, gvr client.GVR, path string) {
+func (b *Benchmark) viewBench(app *App, _ ui.Tabular, _ *client.GVR, path string) {
 	data, err := readBenchFile(app.Config, b.benchFile())
 	if err != nil {
 		app.Flash().Errf("Unable to load bench file %s", err)
@@ -71,8 +73,10 @@ func fileToSubject(path string) string {
 func benchDir(cfg *config.Config) string {
 	ct, err := cfg.K9s.ActiveContext()
 	if err != nil {
-		log.Error().Err(err).Msgf("no active context located")
+		slog.Error("No active context located", slogs.Error, err)
+		return render.MissingValue
 	}
+
 	return filepath.Join(
 		config.AppBenchmarksDir,
 		data.SanitizeFileName(ct.ClusterName),
